from subprocess import check_output


class Control:
    def _sytemd(self, command):
        args = ['systemctl', command, 'gitbucket.service']
        return check_output(args)

    def enable(self):
        self._sytemd('enable')

    def disable(self):
        self._sytemd('disable')

    def start(self):
        self._sytemd('start')

    def stop(self):
        self._sytemd('stop')

    def is_active(self):
        status_text = self._sytemd('status')
        return 'Active: active' in status_text